@@ -481,7 +481,8 @@ def testTilesFromGreyscale(boundServer, admin, fsAssetstore, girderWorker):
     file = utilities.uploadTestFile('grey10kx5k.tif', admin, fsAssetstore)
     itemId = str(file['itemId'])
     fileId = str(file['_id'])
-    tileMetadata = _postTileViaHttp(boundServer, admin, itemId, fileId)
+    boundServer.request(path='/item/%s/tiles' % itemId, method='DELETE', user=admin)
+    tileMetadata = _postTileViaHttp(boundServer, admin, itemId, fileId, data={'force': True})
     assert tileMetadata['tileWidth'] == 256
     assert tileMetadata['tileHeight'] == 256
     assert tileMetadata['sizeX'] == 10000
@@ -1201,8 +1202,8 @@ def testTilesBandInformation(server, admin, fsAssetstore):
     server.request(path='/item/%s/tiles' % itemId, method='POST', user=admin)
     resp = server.request(path='/item/%s/tiles/bands' % itemId)
     assert len(resp.json) == 4
-    assert resp.json[0]['interpretation'] == 'red'
-    assert 'mean' in resp.json[0]
+    assert resp.json['1']['interpretation'] == 'red'
+    assert 'mean' in resp.json['1']
 
 
 @pytest.mark.usefixtures('unbindLargeImage')
